pub fn script_info(source: &str) -> Result<ScriptInfo, Error>Expand description
Compile a script from source and return its ScriptInfo.
pub fn script_info(source: &str) -> Result<ScriptInfo, Error>Compile a script from source and return its ScriptInfo.