RestoreBuilder

Struct RestoreBuilder 

pub struct RestoreBuilder { /* private fields */ }
Builder returned by Instance::restore_state for configuring optional parameters before completing the restore.

Implementations

Source

impl RestoreBuilder

pub fn with_data_provider<P>(self, provider: P) -> Self
where P: DataProvider + 'static,

Injects a DataProvider to enable request.security() and to supply symbol metadata.

pub fn build(self) -> Result<Instance, SnapshotError>

Finishes restoring the instance from the snapshot.

Errors

Returns SnapshotError if the object table contains invalid references or objects cannot be reconstructed.