TimeFrame

Struct TimeFrame 

pub struct TimeFrame {
    pub quantity: NonZero<u32>,
    pub unit: TimeUnit,
}
Represents a timeframe with a quantity and a unit.

Timeframes specify the bar duration for chart data (e.g. 1 day, 5 minutes). They can be created with convenience constructors, the general new() method, or by parsing a string.

Examples

use navi_types::{TimeFrame, TimeUnit};

// Convenience constructors
let daily = TimeFrame::days(1);
let five_min = TimeFrame::minutes(5);
let weekly = TimeFrame::weeks(1);

// General constructor
let monthly = TimeFrame::new(3, TimeUnit::Month);

// Parse from timeframe strings
let tf: TimeFrame = "D".parse().unwrap(); // 1 day
assert_eq!(tf, TimeFrame::days(1));

let tf: TimeFrame = "60".parse().unwrap(); // 60 minutes
assert_eq!(tf, TimeFrame::minutes(60));

let tf: TimeFrame = "4W".parse().unwrap(); // 4 weeks
assert_eq!(tf, TimeFrame::weeks(4));

// Display back to string
assert_eq!(TimeFrame::days(1).to_string(), "D");
assert_eq!(TimeFrame::minutes(5).to_string(), "5");
assert_eq!(TimeFrame::months(3).to_string(), "3M");

Fields

quantity: NonZero<u32>

Number of units in the timeframe.

unit: TimeUnit

Base unit for the timeframe.

Implementations



impl TimeFrame

pub fn new(quantity: u32, unit: TimeUnit) -> TimeFrame

Creates a new TimeFrame with the given quantity and unit.

Panics

Panics if quantity is zero.

pub fn seconds(quantity: u32) -> TimeFrame

Creates a TimeFrame representing the given number of seconds.

pub fn minutes(quantity: u32) -> TimeFrame

Creates a TimeFrame representing the given number of minutes.

pub fn days(quantity: u32) -> TimeFrame

Creates a TimeFrame representing the given number of days.

pub fn weeks(quantity: u32) -> TimeFrame

Creates a TimeFrame representing the given number of weeks.

pub fn months(quantity: u32) -> TimeFrame

Creates a TimeFrame representing the given number of months.

pub fn ticks(quantity: u32) -> TimeFrame

Creates a TimeFrame representing the given number of ticks.

pub fn multiplier(&self) -> u32

Returns the multiplier (quantity) of the timeframe.

For example, ‘60’ - 60, ‘D’ - 1, ‘5W’ - 5.

pub fn in_seconds(&self) -> Option<u64>

Returns the timeframe duration in seconds, if representable.

pub fn from_seconds(seconds: i64) -> TimeFrame

Chooses a coarse TimeFrame that best fits seconds.

pub fn round( &self, session_start: &Time, time: &PrimitiveDateTime, ) -> Option<PrimitiveDateTime>

Rounds time down to the start of the bar this timeframe would contain it in.

pub fn close( &self, session_start: &Time, time: &PrimitiveDateTime, ) -> Option<PrimitiveDateTime>

Returns the close time of the bar that contains time.